@@ -1,3 +1,4 @@
+#![allow(dead_code)]
 use marlu::num_traits::{Float, Num};
 
 pub use crate::{approx, Complex, Jones};
@@ -5,6 +6,12 @@ pub use crate::{approx, Complex, Jones};
 #[derive(Clone, Copy, Default, PartialEq)]
 pub(crate) struct TestJones<F: Float + Num>(Jones<F>);
 
+impl<F: Float> TestJones<F> {
+    pub fn identity() -> TestJones<F> {
+        TestJones(Jones::<F>::identity())
+    }
+}
+
 impl<F: Float> From<Jones<F>> for TestJones<F> {
     #[inline]
     fn from(j: Jones<F>) -> Self {
@@ -12,6 +19,30 @@ impl<F: Float> From<Jones<F>> for TestJones<F> {
     }
 }
 
+impl From<Jones<f32>> for TestJones<f64> {
+    #[inline]
+    fn from(j_c32: Jones<f32>) -> Self {
+        Self::from([
+            Complex::new(j_c32[0].re as _, j_c32[0].im as _),
+            Complex::new(j_c32[1].re as _, j_c32[1].im as _),
+            Complex::new(j_c32[2].re as _, j_c32[2].im as _),
+            Complex::new(j_c32[3].re as _, j_c32[3].im as _),
+        ])
+    }
+}
+
+impl From<Jones<f64>> for TestJones<f32> {
+    #[inline]
+    fn from(j_c32: Jones<f64>) -> Self {
+        Self::from([
+            Complex::new(j_c32[0].re as _, j_c32[0].im as _),
+            Complex::new(j_c32[1].re as _, j_c32[1].im as _),
+            Complex::new(j_c32[2].re as _, j_c32[2].im as _),
+            Complex::new(j_c32[3].re as _, j_c32[3].im as _),
+        ])
+    }
+}
+
 impl<F: Float> From<[Complex<F>; 4]> for TestJones<F> {
     #[inline]
     fn from(j: [Complex<F>; 4]) -> Self {
